@@ -9,14 +9,15 @@ use std::path::PathBuf;
 
 mod index;
 mod song;
-mod sqlite;
 mod toml;
 
+pub mod sqlite;
+
 #[dynamic]
 pub static GONK_DIR: PathBuf = {
     let gonk = dirs::config_dir().unwrap().join("gonk");
     if !gonk.exists() {
-        std::fs::create_dir_all(GONK_DIR.as_path()).unwrap();
+        std::fs::create_dir_all(&gonk).unwrap();
     }
     gonk
 };
