@@ -3,10 +3,10 @@ use dpc_pariter::IteratorExt;
 use jwalk::WalkDir;
 use r2d2::{Pool, PooledConnection};
 use r2d2_sqlite::SqliteConnectionManager;
-use rusqlite::{params, Connection, Params, Row};
+use rusqlite::{params, Params, Row};
 use static_init::dynamic;
 use std::{
-    path::PathBuf,
+    path::{Path, PathBuf},
     sync::{
         atomic::{AtomicBool, Ordering},
         Arc,
@@ -48,36 +48,6 @@ static CONN: Pool<SqliteConnectionManager> = {
 fn conn() -> PooledConnection<SqliteConnectionManager> {
     CONN.get().unwrap()
 }
-fn fix(item: &str) -> String {
-    item.replace('\'', r"''")
-}
-fn collect_songs<P>(query: &str, params: P) -> Vec<Song>
-where
-    P: Params,
-{
-    let conn = conn();
-    let mut stmt = conn.prepare(query).unwrap();
-
-    stmt.query_map(params, |row| Ok(song(row)))
-        .unwrap()
-        .flatten()
-        .collect()
-}
-fn song(row: &Row) -> Song {
-    let path: String = row.get(5).unwrap();
-    let dur: f64 = row.get(6).unwrap();
-    Song {
-        number: row.get(0).unwrap(),
-        disc: row.get(1).unwrap(),
-        name: row.get(2).unwrap(),
-        album: row.get(3).unwrap(),
-        artist: row.get(4).unwrap(),
-        duration: Duration::from_secs_f64(dur),
-        path: PathBuf::from(path),
-        track_gain: row.get(7).unwrap(),
-    }
-}
-
 pub fn get_all_songs() -> Vec<(usize, Song)> {
     let conn = conn();
     let mut stmt = conn.prepare("SELECT *, rowid FROM song").unwrap();
@@ -149,7 +119,6 @@ pub fn get_song(song: &(u64, String), album: &str, artist: &str) -> Vec<Song> {
         params![song.1, song.0, artist, album],
     )
 }
-
 pub fn get_songs_from_id(ids: &[usize]) -> Vec<Song> {
     ids.iter()
         .filter_map(|id| {
@@ -159,6 +128,39 @@ pub fn get_songs_from_id(ids: &[usize]) -> Vec<Song> {
         })
         .collect()
 }
+fn collect_songs<P>(query: &str, params: P) -> Vec<Song>
+where
+    P: Params,
+{
+    let conn = conn();
+    let mut stmt = conn.prepare(query).unwrap();
+
+    stmt.query_map(params, |row| Ok(song(row)))
+        .unwrap()
+        .flatten()
+        .collect()
+}
+fn fix(item: &str) -> String {
+    item.replace('\'', r"''")
+}
+fn song(row: &Row) -> Song {
+    let path: String = row.get(5).unwrap();
+    let dur: f64 = row.get(6).unwrap();
+    Song {
+        number: row.get(0).unwrap(),
+        disc: row.get(1).unwrap(),
+        name: row.get(2).unwrap(),
+        album: row.get(3).unwrap(),
+        artist: row.get(4).unwrap(),
+        duration: Duration::from_secs_f64(dur),
+        path: PathBuf::from(path),
+        track_gain: row.get(7).unwrap(),
+    }
+}
+pub fn reset() {
+    let conn = conn();
+    conn.execute("DELETE FROM song", []).unwrap();
+}
 
 #[derive(Default)]
 pub struct Database {
@@ -213,22 +215,26 @@ impl Database {
 
         thread::spawn(move || {
             for dir in dirs {
+                if !Path::new(&dir).exists() {
+                    break;
+                }
                 let songs: Vec<Song> = WalkDir::new(&dir)
                     .into_iter()
-                    .map(|dir| dir.unwrap().path())
-                    .filter(|dir| {
-                        if let Some(ex) = dir.extension() {
+                    .flatten()
+                    .map(|dir| dir.path())
+                    .filter(|path| match path.extension() {
+                        Some(ex) => {
                             matches!(ex.to_str(), Some("flac" | "mp3" | "ogg" | "wav" | "m4a"))
-                        } else {
-                            false
                         }
+                        None => false,
                     })
-                    .parallel_map(|dir| Song::from(&dir))
+                    .parallel_map(|dir| Song::from(&dir).unwrap())
                     .collect();
 
                 if songs.is_empty() {
                     return;
                 }
+
                 let mut stmt = String::from("BEGIN;\n");
                 stmt.push_str(&songs.iter()
                 .map(|song| {
@@ -245,7 +251,7 @@ impl Database {
 
                 stmt.push_str("COMMIT;\n");
 
-                let conn = Connection::open(DB_DIR.as_path()).unwrap();
+                let conn = conn();
                 conn.execute_batch(&stmt).unwrap();
             }
 
